==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/Performance/src/com/clustercontrol/performance/monitor/action/GetPerformance.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.action;

import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.quartz.SchedulerException;

import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.performance.monitor.util.EjbConnectionManager;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfController;

/**
 * ꥽ƻ륯饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetPerformance {

    /**
     * ʹƻ֤ޤ
     * 
     * @param monitorId ִƻID
     * @return ʹƻ
     */
    public MonitorInfo getProcess(String monitorId) {

    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager().getMonitorPerfController();

    	MonitorInfo info = null;
        try {
        	info = ctr.getPerformance(monitorId);
        } catch (RemoteException e) {
        } catch (CreateException e) {
        } catch (FinderException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        }
        return info;
    }
    
    /**
     * ʹƻ֤ޤ
     * 
     * @return ʹƻ
     */
    public ArrayList getProcessList() {

    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager()
                .getMonitorPerfController();

        ArrayList records = null;
        try {
            records = ctr.getPerformanceList();
        } catch (RemoteException e) {
        } catch (CreateException e) {
        } catch (FinderException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        }
        return records;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/Performance/src/com/clustercontrol/performance/monitor/action/GetPerformance.java <==
/*

 Copyright (C) 2006 NTT DATA Corporation

 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License
 as published by the Free Software Foundation, version 2.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 */

package com.clustercontrol.performance.monitor.action;

import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.quartz.SchedulerException;

import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.performance.monitor.util.EjbConnectionManager;
import com.clustercontrol.performanceMGR.monitor.ejb.session.MonitorPerfController;

/**
 * リソース監視を取得するクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetPerformance {

    /**
     * 閾値監視情報を返します。
     * 
     * @param monitorId 状態監視ID
     * @return 閾値監視情報
     */
    public MonitorInfo getProcess(String monitorId) {

    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager().getMonitorPerfController();

    	MonitorInfo info = null;
        try {
        	info = ctr.getPerformance(monitorId);
        } catch (RemoteException e) {
        } catch (CreateException e) {
        } catch (FinderException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        }
        return info;
    }
    
    /**
     * 閾値監視一覧を返します。
     * 
     * @return 閾値監視一覧
     */
    public ArrayList getProcessList() {

    	MonitorPerfController ctr = EjbConnectionManager.getConnectionManager()
                .getMonitorPerfController();

        ArrayList records = null;
        try {
            records = ctr.getPerformanceList();
        } catch (RemoteException e) {
        } catch (CreateException e) {
        } catch (FinderException e) {
        } catch (SchedulerException e) {
        } catch (NamingException e) {
        }
        return records;
    }
}
